@@ -17,5 +17,5 @@ r = Repo(repo_path)
 
 commit = r[commit_id]
 parent_commit = r[commit.parents[0]]
-outstream = getattr(sys.stdout, 'buffer', sys.stdout)
+outstream = getattr(sys.stdout, "buffer", sys.stdout)
 write_tree_diff(outstream, r.object_store, parent_commit.tree, commit.tree)
