@@ -25,7 +25,6 @@ import sys
 import tempfile
 import warnings
 from io import BytesIO
-from typing import Dict
 from unittest.mock import patch
 from urllib.parse import quote as urlquote
 from urllib.parse import urlparse
@@ -47,6 +46,7 @@ from dulwich.client import (
     SubprocessSSHVendor,
     TCPGitClient,
     TraditionalGitClient,
+    _extract_symrefs_and_agent,
     _remote_error_from_stderr,
     check_wants,
     default_urllib3_manager,
@@ -1093,7 +1093,7 @@ class HttpGitClientTests(TestCase):
         # otherwise without an active internet connection
         class PoolManagerMock:
             def __init__(self) -> None:
-                self.headers: Dict[str, str] = {}
+                self.headers: dict[str, str] = {}
 
             def request(
                 self,
@@ -1137,7 +1137,9 @@ class HttpGitClientTests(TestCase):
             # instantiate HttpGitClient with mocked pool manager
             c = HttpGitClient(base_url, pool_manager=pool_manager, config=None)
             # call method that detects url redirection
-            _, _, processed_url = c._discover_references(b"git-upload-pack", base_url)
+            _, _, processed_url, _, _ = c._discover_references(
+                b"git-upload-pack", base_url
+            )
 
             # send the same request as the method above without redirection
             resp = c.pool_manager.request("GET", base_url + tail, redirect=False)
@@ -1162,7 +1164,7 @@ class HttpGitClientTests(TestCase):
         # otherwise without an active internet connection
         class PoolManagerMock:
             def __init__(self) -> None:
-                self.headers: Dict[str, str] = {}
+                self.headers: dict[str, str] = {}
 
             def request(
                 self,
@@ -1197,7 +1199,7 @@ class HttpGitClientTests(TestCase):
         # otherwise without an active internet connection
         class PoolManagerMock:
             def __init__(self) -> None:
-                self.headers: Dict[str, str] = {}
+                self.headers: dict[str, str] = {}
 
             def request(
                 self,
@@ -1867,3 +1869,12 @@ And this line is just random noise, too.
                 ]
             ),
         )
+
+
+class TestExtractAgentAndSymrefs(TestCase):
+    def test_extract_agent_and_symrefs(self):
+        (symrefs, agent) = _extract_symrefs_and_agent(
+            [b"agent=git/2.31.1", b"symref=HEAD:refs/heads/master"]
+        )
+        self.assertEqual(agent, b"git/2.31.1")
+        self.assertEqual(symrefs, {b"HEAD": b"refs/heads/master"})
